## CHANGELOG

### 0.5.0 - 2020-04-26

 - Improve repositories interface

 - Create tests for datastore repositories

### 0.4.1 - 2020-04-25

 - Improve datastore repositories

### 0.4.0 - 2020-04-25

 - Improve repositories interface

 - Add support for TypedDict

 - Improve sorted set entity

 - Improve coverage

### 0.3.0 - 2020-04-25

 - Create new tests and fix some bugs

 - Add subclass validation for MemoryRepository

### 0.2.1 - 2020-04-25

 - Fix DatastoreDataSource.make_key method

### 0.2.0 - 2020-04-24

 - Create dbdaora package
